@@ -20,6 +20,7 @@ use crate::service_interface::ServiceInterface;
 use super::AppServiceError;
 
 use fluence_faas::FluenceFaaS;
+use fluence_faas::IValue;
 use serde_json::Value as JValue;
 
 use std::convert::TryInto;
@@ -69,7 +70,7 @@ impl AppService {
         })
     }
 
-    /// Call a specified function of loaded module by its name.
+    /// Call a specified function of loaded module by its name with arguments in json format.
     // TODO: replace serde_json::Value with Vec<u8>?
     pub fn call<S: AsRef<str>>(
         &mut self,
@@ -87,6 +88,23 @@ impl AppService {
             .map_err(Into::into)
     }
 
+    /// Call a specified function of loaded module by its name with arguments in IValue format.
+    pub fn call_with_ivalues<S: AsRef<str>>(
+        &mut self,
+        func_name: S,
+        arguments: &[IValue],
+        call_parameters: crate::CallParameters,
+    ) -> Result<Vec<IValue>> {
+        self.faas
+            .call_with_ivalues(
+                &self.facade_module_name,
+                func_name,
+                arguments,
+                call_parameters,
+            )
+            .map_err(Into::into)
+    }
+
     /// Return interface (function signatures and record types) of this service.
     pub fn get_interface(&self) -> ServiceInterface {
         use crate::service_interface::into_service_interface;
@@ -96,7 +114,7 @@ impl AppService {
             .get_interface()
             .modules
             .remove(self.facade_module_name.as_str())
-            // facade module must be loaded in FaaS, so unwrap is safe here
+            // facade module must be loaded into FaaS, so unwrap is safe here
             .unwrap();
 
         into_service_interface(faas_facade_interface)
@@ -205,7 +223,7 @@ impl AppService {
         fluence_faas::FaaSError: From<C::Error>,
     {
         self.faas
-            .load_module(name, &wasm_bytes, config)
+            .load_module(name, wasm_bytes, config)
             .map_err(Into::into)
     }
 
